@@ -32,77 +32,6 @@ Estimating the susceptibility distortions without fieldmaps.
     >>> nb.Nifti1Image(data, None, None).to_filename(
     ...     tmpdir.join('field.nii.gz').strpath)
 
-.. _sdc_fieldmapless :
-
-Fieldmap-less approaches
-~~~~~~~~~~~~~~~~~~~~~~~~
-Many studies acquired (especially with legacy MRI protocols) do not have any
-information to estimate susceptibility-derived distortions.
-In the absence of data with the specific purpose of estimating the :math:`B_0`
-inhomogeneity map, researchers resort to nonlinear registration to an
-«*anatomically correct*» map of the same individual (normally acquired with
-:abbr:`T1w (T1-weighted)`, or :abbr:`T2w (T2-weighted)` sequences).
-One of the most prominent proposals of this approach is found in [Studholme2000]_.
-
-*SDCFlows* includes an (experimental) procedure, based on nonlinear image registration
-with ANTs' symmetric normalization (SyN) technique.
-This workflow takes a skull-stripped :abbr:`T1w (T1-weighted)` image and
-a reference :abbr:`EPI (Echo-Planar Imaging)` image, and estimates a field of nonlinear
-displacements that accounts for susceptibility-derived distortions.
-To more accurately estimate the warping on typically distorted regions, this
-implementation uses an average :math:`B_0` mapping described in [Treiber2016]_.
-The implementation is a variation on those developed in [Huntenburg2014]_ and
-[Wang2017]_.
-
-The process is divided in two steps.
-First, the two images to be aligned (anatomical and one or more EPI sources) are prepared for
-registration, including a linear pre-alignment of both, calculation of a 3D EPI *reference* map,
-intensity/histogram enhancement, and *deobliquing* (meaning, for images were the physical
-coordinates axes and the data array axes are not aligned, the physical coordinates are
-rotated to align with the data array).
-Such a preprocessing is implemented in :py:func:`init_syn_preprocessing_wf`.
-Second, the outputs of the preprocessing workflow are fed into :py:func:`init_syn_sdc_wf`,
-which executes the nonlinear, SyN registration.
-To aid the *Mattes* mutual information cost function, the registration scheme is set up
-in *multi-channel* mode, and laplacian-filtered derivatives of both anatomical and EPI
-reference are introduced as a second registration channel.
-The optimization gradients of the registration process are weighted, so that deformations
-effectively possible only along the :abbr:`PE (phase-encoding)` axis.
-Given that ANTs' registration framework performs on physical coordinates, it is necessary
-that input images are not *oblique*.
-The anatomical image is used as *fixed image*, and therefore, the registration process
-estimates the transformation function from *unwarped* (anatomically *correct*) coordinates
-to *distorted* coordinates.
-If fed into ``antsApplyTransforms``, the resulting transform will effectively *unwarp* a distorted
-EPI given as input into its *unwarped* mapping.
-The estimated transform is then converted into a :math:`B_0` fieldmap in Hz, which can be
-stored within the derivatives folder.
-
-.. danger :: Experimental feature
-
-    This procedure is experimental, and the outcomes should be scrutinized one-by-one
-    and used with caution.
-    Feedback will be enthusiastically received.
-
-References
-----------
-.. [Studholme2000] Studholme et al. (2000) Accurate alignment of functional EPI data to
-    anatomical MRI using a physics-based distortion model,
-    IEEE Trans Med Imag 19(11):1115-1127, 2000, doi: `10.1109/42.896788
-    <https://doi.org/10.1109/42.896788>`__.
-.. [Treiber2016] Treiber, J. M. et al. (2016) Characterization and Correction
-    of Geometric Distortions in 814 Diffusion Weighted Images,
-    PLoS ONE 11(3): e0152472. doi:`10.1371/journal.pone.0152472
-    <https://doi.org/10.1371/journal.pone.0152472>`_.
-.. [Wang2017] Wang S, et al. (2017) Evaluation of Field Map and Nonlinear
-    Registration Methods for Correction of Susceptibility Artifacts
-    in Diffusion MRI. Front. Neuroinform. 11:17.
-    doi:`10.3389/fninf.2017.00017
-    <https://doi.org/10.3389/fninf.2017.00017>`_.
-.. [Huntenburg2014] Huntenburg, J. M. (2014) `Evaluating Nonlinear
-    Coregistration of BOLD EPI and T1w Images
-    <http://pubman.mpdl.mpg.de/pubman/item/escidoc:2327525:5/component/escidoc:2327523/master_thesis_huntenburg_4686947.pdf>`__,
-    Berlin: Master Thesis, Freie Universität.
 
 """
 from pkg_resources import resource_filename
